%PLOTROBUSTCONTROL - Dieses Skript veranschaulicht die Ergebnisse einer 
% robusten Polbereichsvorgabe-Regelung.
%
% Vor der Ausfhrung des Skripts mssen die Simulationen robrega.mdl, 
% robregb.mdl, robregc.mdl, robegd.mdl durchgefhrt werden. Diese Speichern
% die entsprechenden Simulationsergebnisse in den Workspace.
%
% Autor: Mathias Kluwe
% Insitut fr Regelung und Steurungssysteme (IRS)
% Karlsruher Institut fr Technologie
% Website: http://www.irs.kit.edu
% Letzte nderung: 27-Juni-2016 von Jona Maurer
%
%------------- BEGIN CODE --------------

%% init
close all
clc 

linesize = 2;
textsize = 16;

%% Plotting
% Plot zur Stellgre
figure(1)
plot(ua(:,1),ua(:,2),'r',ub(:,1),ub(:,2),'g',uc(:,1),uc(:,2),'k',ud(:,1),ud(:,2),'b','linewidth',linesize)
xlabel('Zeit','FontSize',textsize)
ylabel('u in N','FontSize',textsize)
set(gca,'linewidth',linesize,'Fontsize',textsize)
set(gca,'YLim',[-2500,6000])
legend('    50kg 10m','4000kg 10m','    50kg 12m','    50kg   4m')
title('Stellgroesse')

% Plot zum Winkel
figure(2)
plot(x3a(:,1),x3a(:,2)*360/(2*pi),'r',x3b(:,1),x3b(:,2)*360/(2*pi),'g',...
        x3c(:,1),x3c(:,2)*360/(2*pi),'k',x3d(:,1),x3d(:,2)*360/(2*pi),'b','linewidth',linesize)
xlabel('Zeit','FontSize',textsize)
ylabel('x_3(t) in grad','FontSize',textsize)
set(gca,'linewidth',linesize,'Fontsize',textsize)
set(gca,'YLim',[-15,5])
legend('    50kg 10m','4000kg 10m','    50kg 12m','    50kg   4m',4)
title('Winkelauslenkung')

% Plot zur Position
figure(3)
plot(x1a(:,1),x1a(:,2),'r',x1b(:,1),x1b(:,2),'g',x1c(:,1),x1c(:,2),'k',x1d(:,1),x1d(:,2),'b','linewidth',linesize)
xlabel('Zeit','FontSize',textsize)
ylabel('x_1(t) in m','FontSize',textsize)
set(gca,'linewidth',linesize,'Fontsize',textsize)
set(gca,'YLim',[0,10])
legend('    50kg 10m','4000kg 10m','    50kg 12m','    50kg   4m',4)
title('Position')

%------------- END CODE --------------